/*
 * buttons.c
 *
 * Copyright 2019 Thomas Gollmer <th_goso@freenet.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 *
 *
 * Taster/Schalter lesen
 *
 */
#include <avr/io.h>
#include <util/delay.h>
#include "light.h"
#include "buttons.h"

#define BL_ON_SECONDS  10


/***********************************************************************************************************************
 * Öffentliche Funktion
 *
 * Initialisierung Schalter/Taster Eingänge
 * PD5...PD2 -> Alles Eingänge mit internem Pull-Up aktiviert
 **********************************************************************************************************************/
void buttons_init (void)
{
  PORTD |= 0b00111100;
}
/***********************************************************************************************************************
 * Öffentliche Funktion
 *
 * Liest Stellung Alarm An/Aus Schalter an PD5 ein und gibt diese zurück
 * Rückgabe:  SWITCH____
 *
 * Schaltet DisplayBeleuchtung ein, falls sich Schalterstatus seit letztem Aufruf geändert hat
 **********************************************************************************************************************/
uint8_t alarm_switch_get_state (void)
{
  static uint8_t last = 255;
  uint8_t cur;

  if ((PIND & 0b00100000) == 0) cur = SWITCH_ON;
  else cur = SWITCH_OFF;

  if (last != cur) {
    last = cur;
    backlight_set_on(BL_ON_SECONDS);
  }
  return cur;
}
/***********************************************************************************************************************
 * Öffentliche Funktion
 *
 * Liest Buttonstatus ein und gibt Konstannte für gedrückte Taste zurück oder KEINE gedrückt
 * PD4 = Rechts, PD3 = Taste Mitte, PD2 = Taste Links
 **********************************************************************************************************************/
uint8_t buttons_get_state (void)
{
  uint8_t btn = PIND & 0b00011100;
  uint8_t ret;

  if      (btn == 0b00001100) ret = BUTTON_PRESSED_RIGHT;
  else if (btn == 0b00010100) ret =  BUTTON_PRESSED_MID;
  else if (btn == 0b00011000) ret = BUTTON_PRESSED_LEFT;
  else ret = BUTTON_PRESSED_NONE;

  if (ret != BUTTON_PRESSED_NONE) backlight_set_on(BL_ON_SECONDS);

  return ret;
}
/***********************************************************************************************************************
 * öffentliche Funktion
 *
 * wartet (prellfrei per delay) bis evtl. Tastendruck losgelassen wird
 **********************************************************************************************************************/
void buttons_wait_release (void)
{
  uint8_t btn;

  while (1) {
    btn = buttons_get_state();
    if (btn == BUTTON_PRESSED_NONE) break;
  }
  _delay_ms(25);
}
