#ifndef MY_LIGHT
#define MY_LIGHT

// ---------------------------------------------------------------------------------------------------------------------
// Initialisierung Licht/Ausgang
void light_init (void);
// ---------------------------------------------------------------------------------------------------------------------
// Helligkeit LED Beleuchtung setzten
// 0(aus) ... 255(volle 100%)
void light_set (uint8_t value);
// ---------------------------------------------------------------------------------------------------------------------
// Display Hintergrundbeleuchtung einschalten
// Schaltet automatisch nach übergebener Zeitspanne selbstständig ab
// Übergabe: Ein-Zeit in Sekunden
void backlight_set_on (uint8_t seconds);
// ---------------------------------------------------------------------------------------------------------------------
// 3 Timer Ticker für das hochzählen von 100ms
#define TICKERS           3

#define TICKER_FADEIN     0                                 // für Fade-In-Zeit zählen
#define TICKER_LIGHTIN    1                                 // für Licht-Aufblendzeit zählen
#define TICKER_DISPLAY    2                                 // für Zeit zur Displayaktualisierung zählen

// Startet einen der möglichen 100ms basierten Tickern/Countuptimern beim Wert 0
// Übergabe: Tickernummer 1, 2, 3 (1-basiert)
void ticker100ms_start (uint8_t ticker_no);
// ---------------------------------------------------------------------------------------------------------------------
// Liefert den aktuellen Stand eines der vier  Ticker/Count-Up-Timern
// Nach Start des Tickers wird dieser im IRQ jede 0,1 Sekunde um eins hochgesetzt (ohne Überlauf)
// Übergabe: Tickernummer 1, 2, 3 (1-basiert)
// Rückgabe: aktueller Stand des Tickers
uint16_t ticker100ms_get_value (uint8_t ticker_no);
// ---------------------------------------------------------------------------------------------------------------------
// Startet den Minutenbasierenden Count-Down-Timer
// Übergabe: Anzahl Minuten bis zum Timeout (1...60)
void sleeptimer_set_minutes_until_sleep (uint8_t minutes);
// ---------------------------------------------------------------------------------------------------------------------
// Holt den aktuellen Stand des Count-Down-Timers ab und gibt ihn zurück
// Timer wird im IRQ inkrementiert und bleibt bei Ablauf bei 0 stehen (ohne Unterlauf)
uint8_t sleeptimer_get_minutes_until_sleep (void);
// ---------------------------------------------------------------------------------------------------------------------

#endif
